summaryrefslogtreecommitdiff
path: root/include/users.h
diff options
context:
space:
mode:
Diffstat (limited to 'include/users.h')
-rw-r--r--include/users.h6
1 files changed, 3 insertions, 3 deletions
diff --git a/include/users.h b/include/users.h
index 88858b160..bcddab1bf 100644
--- a/include/users.h
+++ b/include/users.h
@@ -308,7 +308,7 @@ class CoreExport User : public Extensible
*/
std::string ident;
- /** The users full name (GECOS).
+ /** The users full name.
*/
std::string fullname;
@@ -707,10 +707,10 @@ class CoreExport User : public Extensible
* ALWAYS use this function, rather than writing User::fullname directly,
* as this triggers module events allowing the change to be syncronized to
* remote servers.
* @param gecos The user's new realname
* @return True if the change succeeded, false if otherwise
*/
- bool ChangeName(const std::string& gecos);
+ bool ChangeName(const std::string& real);
/** Change a user's nick
* @param newnick The new nick. If equal to the users uuid, the nick change always succeeds.
@@ -707,10 +707,10 @@ class CoreExport User : public Extensible
* as this triggers module events allowing the change to be syncronized to
* remote servers.
- * @param gecos The user's new realname
+ * @param real The user's new real name
* @return True if the change succeeded, false if otherwise
*/